# ReferenceModel

## How to find and instantiate this model
TODO: Must find a way of dynamically importing models

Clues here: https://stackoverflow.com/questions/42401495/how-to-dynamically-import-modules#42402095 

``` python
>>> from reference_model import reference_model
>>> from vipscore_common.vips_model import VIPSModel
>>> print(VIPSModel.__subclasses__())
[<class 'reference_model.reference_model.ReferenceModel'>]
>>> print(VIPSModel.__subclasses__()[0])
<class 'reference_model.reference_model.ReferenceModel'>
>>> t = VIPSModel.__subclasses__()[0]()
>>> t
<reference_model.reference_model.ReferenceModel object at 0x7f8fab6dee30>
>>> t.get_model_name()
'Reference Model'
>>> t.get_model_description()
"\n        The model is a reference model for developers, showcasing best practices and functionalities of a model.\n        It's a simple day degree model for an imagined pest, and when thresholds are passed, the warning status progresses.\n        "

```

## Testing
The tests are located in the `tests` folder, and we're using [Pytest](https://docs.pytest.org/)

To run the unit tests, move to the root folder of the project, and execute:

``` bash
pytest -v
```

### Using bumpver
For developers: When you want to publish a new version, use
``` bash
# Increment the PATCH version when you make backwards compatible bug fixes.
bumpver update --patch
# Increment the MINOR version when you add functionality in a backwards compatible manner.
bumpver update --minor
# Increment the MAJOR version when you make incompatible API changes.
bumpver update --major
```
[(Source)](https://semver.org/#summary)

## References
We used this excellent guide for packaging: https://realpython.com/pypi-publish-python-package/ 

## Translations
We're using a simple dictionary translation system, with a module translations.py, where we
simply define some dictionaries with language codes as property, looking like this:

```python
name = {
    "en":   "Reference Model",
    "nb":   "Referansemodell",
}
```

This is used in the main module like this:

```python
[...]
from . import translations
[...]
def get_model_name(self, language = VIPSModel.default_language) -> str:
        """Returns the model name in the specified language (<a href="http://www.loc.gov/standards/iso639-2/php/English_list.php">ISO-639-2</a>)"""
        return translations.name.get(language, translations.name.get(VIPSModel.default_language, "NOT FOUND"))  
[...]
```